@@ -17,6 +17,24 @@ import cssutils
 
 from rules import rules as tr_rules
 
+def magic(ruleset, debug):
+    added = ''
+    if hasattr(ruleset, 'style'): # Comments don't
+        for rule in ruleset.style.children():
+            try:
+                processor = tr_rules[rule.name](rule)
+                [ruleset.style.setProperty(prop) for prop in processor.get_prefixed_props()]
+                added += processor.add_to_sheet
+                if hasattr(processor, 'replace_hook'):
+                    ruleset.cssText = processor.replace_hook(ruleset.cssText)
+            except:
+                if debug:
+                    print 'warning with ' + str(rule)
+    elif hasattr(ruleset, 'cssRules'):
+        for subruleset in ruleset:
+            magic(subruleset, debug)
+    return unicode(ruleset.cssText) + added
+
 def process(string, debug=False, minify=False):
     if debug:
         loglevel = 'info'
@@ -30,21 +48,15 @@ def process(string, debug=False, minify=False):
     sheet = parser.parseString(string)
     result = ''
     for ruleset in sheet.cssRules:
-        if hasattr(ruleset, 'style'): # Comments don't
-            for rule in ruleset.style.children():
-                try:
-                    processor = tr_rules[rule.name](rule)
-                    [ruleset.style.setProperty(prop) for prop in processor.get_prefixed_props()]
-                    result += processor.add_to_sheet
-                    if hasattr(processor, 'replace_hook'):
-                        ruleset.cssText = processor.replace_hook(ruleset.cssText)
-                except: # Comments, etc.
-                    if debug:
-                        print 'warning with ' + str(rule)
-            result += unicode(ruleset.cssText)
+        result += magic(ruleset, debug)
 
     # Not using sheet.cssText - it's buggy:
     # it skips some prefixed properties.
     return result
 
 __all__ = ('process')
+
+
+
+
+
